@@ -18,11 +18,11 @@
 #include "renvironmentobject.h"
 
 #include <kmessagebox.h>
-#include <klocale.h>
+#include <KLocalizedString>
 
 #include "robjectlist.h"
 #include "rkpseudoobjects.h"
-#include "../rbackend/rinterface.h"
+#include "../rbackend/rkrinterface.h"
 #include "../settings/rksettingsmoduleobjectbrowser.h"
 #include "rkmodificationtracker.h"
 #include "../rkglobals.h"
