@@ -17,7 +17,7 @@
 
 #include "rkpseudoobjects.h"
 
-#include <klocale.h>
+#include <KLocalizedString>
 
 #include "../debug.h"
 
