@@ -35,8 +35,8 @@ public:
 	explicit RSlotsPseudoObject (RObject *parent);
 	~RSlotsPseudoObject ();
 
-	QString getFullName () const;
-	QString makeChildName (const QString &short_child_name, bool misplaced=false) const;
+	QString getFullName () const override;
+	QString makeChildName (const QString &short_child_name, bool misplaced=false) const override;
 };
 
 /**
@@ -51,9 +51,9 @@ public:
 	explicit RKNamespaceObject (REnvironmentObject* package, const QString name = QString ());
 	~RKNamespaceObject ();
 
-	QString getFullName () const;
-	QString makeChildName (const QString &short_child_name, bool misplaced=false) const;
-	QString makeChildBaseName (const QString &short_child_name) const;
+	QString getFullName () const override;
+	QString makeChildName (const QString &short_child_name, bool misplaced=false) const override;
+	QString makeChildBaseName (const QString &short_child_name) const override;
 	QString namespaceName () const { return namespace_name; };
 private:
 	QString namespace_name;
@@ -75,17 +75,17 @@ public:
 	explicit RKOrphanNamespacesObject (RObjectList *parent);
 	~RKOrphanNamespacesObject ();
 
-	QString getFullName () const;
-	QString makeChildName (const QString &short_child_name, bool misplaced=false) const;
-	QString makeChildBaseName (const QString &short_child_name) const;
-	QString getObjectDescription () const;
+	QString getFullName () const override;
+	QString makeChildName (const QString &short_child_name, bool misplaced=false) const override;
+	QString makeChildBaseName (const QString &short_child_name) const override;
+	QString getObjectDescription () const override;
 
 	RKNamespaceObject *findOrphanNamespace (const QString &name) const;
 
 	/** should not be called on this object. Reimplemented to raise an assert, and do nothing else. */
-	void updateFromR (RCommandChain *chain);
+	void updateFromR (RCommandChain *chain) override;
 	/** reimplemented from REnvironmentObject */
-	void updateFromR (RCommandChain *chain, const QStringList &current_symbols);
+	void updateFromR (RCommandChain *chain, const QStringList &current_symbols) override;
 };
 
 #endif
