@@ -3,7 +3,7 @@
                              -------------------
     begin                : Tue Mar 21 2010
     copyright            : (C) 2010, 2013 by Thomas Friedrichsmeier
-    email                : tfry@users.sourceforge.net
+    email                : thomas.friedrichsmeier@kdemail.net
  ***************************************************************************/
 
 /***************************************************************************
@@ -19,11 +19,11 @@
 
 #include <limits.h>
 
-#include <klocale.h>
+#include <KLocalizedString>
 
 #include "rcontainerobject.h"
 #include "../rkglobals.h"
-#include "../rbackend/rinterface.h"
+#include "../rbackend/rkrinterface.h"
 #include "rkmodificationtracker.h"
 
 #include "../debug.h"
@@ -65,14 +65,14 @@ void RKRowNames::beginEdit () {
 QString RKRowNames::getFullName () const {
 //	RK_TRACE (OBJECTS);
 
-	return ("row.names (" + parent->getFullName () + ")");
+	return ("row.names (" + parent->getFullName () + ')');
 }
 
 void RKRowNames::writeData (int from_row, int to_row, RCommandChain *chain) {
 	RK_TRACE (OBJECTS);
 
 	if (isSequential ()) {
-		RKGlobals::rInterface ()->issueCommand (getFullName () + " <- NULL", RCommand::App | RCommand::Sync, QString::null, 0,0, chain);
+		RKGlobals::rInterface ()->issueCommand (getFullName () + " <- NULL", RCommand::App | RCommand::Sync, QString (), 0,0, chain);
 	} else {
 		// unfortunately, we always need to write the whole data, as row.names<- does not support indexing.
 		QString data_string = "c (";
@@ -84,7 +84,7 @@ void RKRowNames::writeData (int from_row, int to_row, RCommandChain *chain) {
 			}
 		}
 		data_string.append (")");
-		RKGlobals::rInterface ()->issueCommand (getFullName () + " <- " + data_string, RCommand::App | RCommand::Sync, QString::null, 0, 0, chain);
+		RKGlobals::rInterface ()->issueCommand (getFullName () + " <- " + data_string, RCommand::App | RCommand::Sync, QString (), 0, 0, chain);
 	}
 
 	ChangeSet *set = new ChangeSet;
