@@ -18,17 +18,16 @@
 #ifndef RKRECOVERDIALOG_H
 #define RKRECOVERDIALOG_H
 
-#include <kdialog.h>
-
+#include <QDialog>
 #include <QStringList>
 
 /** Dialog to offer loading of recovery files during startup. */
-class RKRecoverDialog : public KDialog {
+class RKRecoverDialog : public QDialog {
 	Q_OBJECT
 public:
 /** Check whether a crash recovery file is available. If so, display a dialog, offering to load the recovery file.
-@returns The url of the recovery file, if user selected to load it. An empty KUrl otherwise. */
-	static KUrl checkRecoverCrashedWorkspace ();
+@returns The url of the recovery file, if user selected to load it. An empty QUrl otherwise. */
+	static QUrl checkRecoverCrashedWorkspace ();
 protected:
 	RKRecoverDialog (const QStringList &recovery_files);
 	~RKRecoverDialog ();
