@@ -2,7 +2,7 @@
                           rkstandardicons  -  description
                              -------------------
     begin                : Wed Oct 24 2007
-    copyright            : (C) 2007, 2009, 2010, 2011, 2015 by Thomas Friedrichsmeier
+    copyright            : (C) 2007-2016 by Thomas Friedrichsmeier
     email                : thomas.friedrichsmeier@kdemail.net
  ***************************************************************************/
 
@@ -29,8 +29,6 @@ Also, since QIcons are only loaded on demand, and implicitely shared, this shoul
 
 Eventually all icons (even those that are only used once, so far) should be added, here. All direct constructions of QIcons (or KIconLoader) should be removed elsewhere.
 
-TODO: we should also have RKStandardActions
-
 @author Thomas Friedrichsmeier */
 class RKStandardIcons {
 public:
@@ -84,6 +82,8 @@ public:
 		ActionLock,
 		ActionUnlock,
 
+		ActionShowMenu,
+
 		ObjectList,
 		ObjectFunction,
 		ObjectEnvironment,
@@ -113,13 +113,15 @@ public:
 		WindowDebugConsole,
 		WindowCallstackViewer,
 
+		StatusWaitingUpdating,
+
 		DocumentPDF,
 
 		Last	/**< not really an item, only the count of items available. Do not use. */
 	};
 
 	/** get the icon with the given name */
-	static QIcon getIcon (IconName name) { return icons[name]; };
+	static QIcon getIcon (IconName name) { return instance->icons[name]; };
 
 	/** convenience function to get the icon most suited for the given RObject */
 	static QIcon iconForObject (const RObject* object);
@@ -127,7 +129,10 @@ public:
 	/** convenience function to get the icon most suited for the given RKMDIWindow */
 	static QIcon iconForWindow (const RKMDIWindow* window);
 private:
-	static QIcon icons[Last];
+	// NOTE: Using a static array of QIcons lead to crashes on exit (Qt 5.4.1). Moving that inside a class instance seems to fix the issue.
+	QIcon icons[Last];
+	void doInitIcons ();
+	static RKStandardIcons* instance;
 };
 
 #endif
