@@ -3,7 +3,7 @@
                              -------------------
     begin                : Fri May 6 2005
     copyright            : (C) 2005, 2007, 2011, 2014 by Thomas Friedrichsmeier
-    email                : tfry@users.sourceforge.net
+    email                : thomas.friedrichsmeier@kdemail.net
  ***************************************************************************/
 
 /***************************************************************************
@@ -37,7 +37,7 @@ public:
 /** create an instance of XMLHelper.
  @param filename the name of the file to parse. The file is not yet opened on construction. Use openXMLFile() for that. 
  @param default_catalog message catalog to use in case none is specified in the xml file itself. */
-	XMLHelper (const QString &filename, const RKMessageCatalog *default_catalog=0);
+	explicit XMLHelper (const QString &filename, const RKMessageCatalog *default_catalog=0);
 /** destructor */
 	~XMLHelper ();
 /** Return the a pointer to the message catalog in use. This may - or may not - be the same as specified as default catalog in the constructor.
