@@ -43,12 +43,11 @@ public:
 	bool isValid ();
 public slots:
 	void textChanged ();
-	void textChanged (const QString &new_text);
-	void textChanged (RKComponentPropertyBase *);
+	void textChangedFromUi ();
 	void requirednessChanged (RKComponentPropertyBase *);
 protected:
 /** Grey out input when disabled */
-	void enabledChange (bool old);
+	void changeEvent (QEvent *event) override;
 private:
 	void updateColor ();
 	bool updating;
