@@ -61,7 +61,7 @@ RKText::RKText (const QDomElement &element, RKComponent *parent_component, QWidg
 	// create and add property
 	addChild ("text", text = new RKComponentPropertyBase (this, true));
 	text->setInternal (true);
-	connect (text, SIGNAL (valueChanged(RKComponentPropertyBase*)), this, SLOT (textChanged(RKComponentPropertyBase*)));
+	connect (text, &RKComponentPropertyBase::valueChanged, this, &RKText::textChanged);
 
 	// initialize
 	text->setValue (initial_text);
@@ -78,4 +78,3 @@ void RKText::textChanged (RKComponentPropertyBase *) {
 	changed ();
 }
 
-#include "rktext.moc"
