@@ -24,7 +24,7 @@
 #include <QMenu>
 #include <QToolButton>
 
-#include <klocale.h>
+#include <KLocalizedString>
 
 #include "../misc/xmlhelper.h"
 #include "../rkglobals.h"
@@ -44,7 +44,7 @@ RKVarSelector::RKVarSelector (const QDomElement &element, RKComponent *parent_co
 	addChild ("selected", selected = new RKComponentPropertyRObjects (this, false));
 	selected->setInternal (true);
 	addChild ("root", root = new RKComponentPropertyRObjects (this, false));
-	connect (root, SIGNAL (valueChanged(RKComponentPropertyBase*)), this, SLOT (rootChanged()));
+	connect (root, &RKComponentPropertyBase::valueChanged, this, &RKVarSelector::rootChanged);
 	root->setInternal (true);
 
 	QVBoxLayout *vbox = new QVBoxLayout (this);
@@ -65,23 +65,23 @@ RKVarSelector::RKVarSelector (const QDomElement &element, RKComponent *parent_co
 	show_all_envs_action = new QAction (i18n ("Show all environments"), this);
 	show_all_envs_action->setCheckable (true);
 	show_all_envs_action->setToolTip (i18n ("Show objects in all environments on the <i>search()</i> path, instead of just those in <i>.GlobalEnv</i>. Check this, if you want to select objects from a loaded package."));
-	connect (show_all_envs_action, SIGNAL (toggled(bool)), this, SLOT (rootChanged()));
+	connect (show_all_envs_action, &QAction::toggled, this, &RKVarSelector::rootChanged);
 
 	filter_widget = 0;
-	filter_widget_placeholder = new QVBoxLayout (this);
+	filter_widget_placeholder = new QVBoxLayout ();
 	filter_widget_placeholder->setContentsMargins (0, 0, 0, 0);
 	vbox->addLayout (filter_widget_placeholder);
 	show_filter_action = new QAction (i18n ("Show filter options"), this);
 	show_filter_action->setCheckable (true);
 	show_filter_action->setShortcut (QKeySequence ("Ctrl+F"));
 	show_filter_action->setIcon (RKStandardIcons::getIcon (RKStandardIcons::ActionSearch));
-	connect (show_filter_action, SIGNAL (toggled(bool)), this, SLOT(showFilterWidget()));
+	connect (show_filter_action, &QAction::toggled, this, &RKVarSelector::showFilterWidget);
 
 	list_view = new RKObjectListView (false, this);
 	list_view->setSelectionMode (QAbstractItemView::ExtendedSelection);
 	list_view->initialize ();
 	vbox->addWidget (list_view);
-	connect (list_view, SIGNAL (selectionChanged()), this, SLOT (objectSelectionChanged()));
+	connect (list_view->selectionModel (), &QItemSelectionModel::selectionChanged, this, &RKVarSelector::objectSelectionChanged);
 
 	QAction* sep = list_view->contextMenu ()->insertSeparator (list_view->contextMenu ()->actions ().value (0));
 	list_view->contextMenu ()->insertAction (sep, show_filter_action);
@@ -127,4 +127,3 @@ void RKVarSelector::objectSelectionChanged () {
 	RK_DEBUG (PLUGIN, DL_DEBUG, "selected in varselector: %s", qPrintable (fetchStringValue (selected)));
 }
 
-#include "rkvarselector.moc"
