@@ -22,11 +22,12 @@
 #include <QTreeWidget>
 #include <QHeaderView>
 #include <qstringlist.h>
+#include <QEvent>
 #include <QGridLayout>
 #include <QVBoxLayout>
+#include <QIcon>
 
-#include <klocale.h>
-#include <kicon.h>
+#include <KLocalizedString>
 
 #include "rkvarselector.h"
 #include "../core/robject.h"
@@ -53,11 +54,11 @@ RKVarSlot::RKVarSlot (const QDomElement &element, RKComponent *parent_component,
 	QVBoxLayout *button_layout = new QVBoxLayout ();
 	select_button = new QPushButton (QString (), this);
 	select_button->setIcon (RKStandardIcons::getIcon (RKStandardIcons::ActionAddRight));
-	connect (select_button, SIGNAL (clicked()), this, SLOT (selectPressed()));
+	connect (select_button, &QPushButton::clicked, this, &RKVarSlot::selectPressed);
 	button_layout->addWidget (select_button);
 	remove_button = new QPushButton (QString (), this);
 	remove_button->setIcon (RKStandardIcons::getIcon (RKStandardIcons::ActionRemoveLeft));
-	connect (remove_button, SIGNAL (clicked()), this, SLOT (removePressed()));
+	connect (remove_button, &QPushButton::clicked, this, &RKVarSlot::removePressed);
 	button_layout->addWidget (remove_button);
 	button_layout->addStretch ();
 	g_layout->addLayout (button_layout, 1, 0);
@@ -89,7 +90,7 @@ RKVarSlot::RKVarSlot (const QDomElement &element, RKComponent *parent_component,
 	// find out about options
 	if ((multi = xml->getBoolAttribute (element, "multi", false, DL_INFO))) {
 		available->setAllowedLength (xml->getIntAttribute (element, "min_vars", 1, DL_INFO), xml->getIntAttribute (element, "min_vars_if_any", 1, DL_INFO), xml->getIntAttribute (element, "max_vars", 0, DL_INFO));
-		connect (list, SIGNAL (itemSelectionChanged()), this, SLOT (listSelectionChanged()));
+		connect (list, &QTreeWidget::itemSelectionChanged, this, &RKVarSlot::listSelectionChanged);
 	} else {
 		available->setAllowedLength (1, 1, 1);
 
@@ -116,7 +117,7 @@ RKVarSlot::RKVarSlot (const QDomElement &element, RKComponent *parent_component,
 	available->setStripDuplicates (!xml->getBoolAttribute (element, "allow_duplicates", false, DL_INFO));
 	setRequired (xml->getBoolAttribute (element, "required", false, DL_INFO));
 
-	connect (available, SIGNAL (valueChanged(RKComponentPropertyBase*)), this, SLOT (availablePropertyChanged(RKComponentPropertyBase*)));
+	connect (available, &RKComponentPropertyBase::valueChanged, this, &RKVarSlot::availablePropertyChanged);
 	availablePropertyChanged (available);	// initialize
 }
 
@@ -166,7 +167,7 @@ void RKVarSlot::availablePropertyChanged (RKComponentPropertyBase *) {
 			QString probs = static_cast<RKComponentPropertyRObjects*> (available)->objectProblems (i);
 			if (!probs.isEmpty ()) {
 				new_item->setToolTip (0, i18n ("<p>Using this object, here, may lead to failures or unexpected results, for the following reason(s):</p>") + probs);
-				new_item->setIcon (0, KIcon ("task-attention"));
+				new_item->setIcon (0, QIcon::fromTheme ("task-attention"));
 			}
 		}
 	}
@@ -193,6 +194,11 @@ void RKVarSlot::updateLook () {
 	list->setPalette(palette);
 }
 
+void RKVarSlot::changeEvent (QEvent* event) {
+	if (event->type () == QEvent::EnabledChange) updateLook ();
+	RKComponent::changeEvent (event);
+}
+
 void RKVarSlot::addOrRemove (bool add) {
 	RK_TRACE (PLUGIN);
 	RK_DEBUG (PLUGIN, DL_DEBUG, "select press in varslot: mode %d, source %s, selected %s", add, qPrintable (fetchStringValue (source)), qPrintable (fetchStringValue (selected)));
@@ -244,4 +250,3 @@ QStringList RKVarSlot::getUiLabelPair () const {
 	return ret;
 }
 
-#include "rkvarslot.moc"
