@@ -2,7 +2,7 @@
 var vars;
 
 function calculate () {
-	vars = trim (getValue ("x")).replace (/\n/g, ", ");
+	vars = getList ("x").join (", ");
 
 	echo ('result <- bartlett.test (list (' + vars + '))\n');
 }
@@ -13,9 +13,9 @@ function printout () {
 	echo ('rk.header (result$method)\n');
 	echo ('\n');
 	echo ('rk.results (list (\n');
-	echo ('	\'Variables\'=names,\n');
-	echo ('	\'Bartlett s K-squared\'=result$statistic,\n');
+	echo ('	' + i18n ("Variables") + '=names,\n');
+	echo ('	' + i18n ("Bartlett's K-squared") + '=result$statistic,\n');
 	echo ('	\'df\'=result$parameter,\n');
-	echo ('	\'p-value\'=result$p.value))\n');
+	echo ('	' + i18n ("p-value") + '=result$p.value))\n');
 }
 
