@@ -17,7 +17,7 @@
 
 #include "rcommand.h"
 #include "rcommandreceiver.h"
-#include "rinterface.h"
+#include "rkrinterface.h"
 #include "../windows/rkcommandlog.h"
 #include "rkrbackendprotocol_shared.h"
 #include "../core/robject.h"
@@ -227,4 +227,3 @@ QString RCommand::rQuote (const QString &quoted) {
 	return RObject::rQuote (quoted);
 }
 
-#include "rcommand.moc"
