@@ -2,8 +2,8 @@
                           rcommand.h  -  description
                              -------------------
     begin                : Mon Nov 11 2002
-    copyright            : (C) 2002, 2006, 2007, 2009, 2010 by Thomas Friedrichsmeier
-    email                : tfry@users.sourceforge.net
+    copyright            : (C) 2002, 2006, 2007, 2009, 2010, 2013 by Thomas Friedrichsmeier
+    email                : thomas.friedrichsmeier@kdemail.net
  ***************************************************************************/
 
 /***************************************************************************
@@ -29,38 +29,28 @@
 class RCommandReceiver;
 class RCommand;
 class RCommandProxy;
-class RCommandChain;
 
-/** Base class for RCommand and RCommandChain, to make it possible to store both in the same list */
-class RCommandBase {
-public:
-/** Returns the casted pointer, if this is a command, else 0 */
-	RCommand* commandPointer ();
-/** Returns the casted pointer, if this is a chain, else 0 */
-	RCommandChain* chainPointer ();
-protected:
-friend class RCommandStack;
-friend class RCommandStackModel;
-	RCommandBase (bool is_chain);
-	RCommandChain *parent;
-private:
-	bool is_command_chain;
-};
-
-/** this simple struct is used to ensure a sequence of RCommand s does not get interrupted by unrelated RCommands.
+/** R Commands can be arranged in a simple chain to make sure they are not interrupted by other commands.
+ *  Also, command may need to run sub-commands.
 @see \ref UsingTheInterfaceToR
 @see RInterface::startChain
 @see RInterface::closeChain */
-class RCommandChain : public RCommandBase {
+class RCommandChain {
 public:
 	bool isClosed () const { return closed; };
+/** @returns true, if there are no sub-commands or sub-chains waiting in this chain */
+	bool isEmpty () const { return sub_commands.isEmpty (); };
+	bool isCommand () const { return is_command; };
+	RCommandChain* parentChain () const { return parent; };
+	RCommand *toCommand ();
 protected:
 friend class RCommandStack;
 friend class RCommandStackModel;
-	RCommandChain () : RCommandBase (true) {};
-	QList<RCommandBase*> commands;
+	RCommandChain (bool is_chain=true) : closed (!is_chain), is_command (!is_chain) {};
+	QList<RCommandChain*> sub_commands;
 	bool closed;
-	bool isStack () { return (parent == 0); }
+	bool is_command;
+	RCommandChain *parent;
 };
 
 /** this struct is used to store the R output to an RCommand. The RCommand basically keeps a list of ROutputString (s). The difference to a normal
@@ -114,7 +104,7 @@ friend class RCommand;
 	kept around very long, so they should not be a memory issue.
   *@author Thomas Friedrichsmeier
   */
-class RCommand : public RData, public RCommandBase {
+class RCommand : public RData, public RCommandChain {
 public:
 /** constructs an RCommand.
 @param command The command (string) to be run in the backend. This may include newlines and ";". The command should be a complete statement. If it is an incomplete statement, the backend will not wait for the rest of the command to come in, but rather the command will fail with RCommand::errorIncomplete.
@@ -123,7 +113,7 @@ public:
 @param receiver The RCommandReceiver this command should be passed on to, when finished. @Note: consider connecting to the notifier(), instead!
 @param flags A freely assignable integer, that you can use to identify what the command was all about. Only the RCommandReceiver handling the results will have to know what exactly the flags mean.
 */
-	explicit RCommand (const QString &command, int type, const QString &rk_equiv = QString::null, RCommandReceiver *receiver=0, int flags=0);
+	explicit RCommand (const QString &command, int type, const QString &rk_equiv = QString (), RCommandReceiver *receiver=0, int flags=0);
 /** destructor. Note: you should not delete RCommands manually. This is done in RInterface. TODO: make protected */
 	~RCommand();
 /** @returns the type as specified in RCommand::RCommand */
@@ -151,22 +141,24 @@ public:
 /** Types of commands (potentially more to come), bitwise or-able,
 	although partially exclusive. See \ref UsingTheInterfaceToR for a overview of what these are used for. TODO: find out, why Canceled is in here, and document that fact. */
 	enum CommandTypes {
-		User=1,		/**< Command was created directly by the user (e.g. in the console or in a command editor window) */
-		Plugin=1 << 1,		/**< Command comes from a plugin */
-		App=1 << 2,			/**< Command comes from the application (e.g. loading / saving the workspace */
-		Sync=1 << 3,		/**< Command is used to sync data to or from R-space. Typically used in the editor classes */
-		EmptyCommand=1 << 4,		/**< Command is empty and will not be processed (an empty command may be used as a "marker") */
-		Console=1 << 5,	/**< Command originated in the console. These commands will get some extra treatment in RKwatch */
-		Internal=1 << 6,	/**< Command is meant to be used in the backend, only. Do not use outside rbackend classes! */
-		Silent=1 << 7,	/**< Command can be interrupted, but is otherwise an internal command. In particular it should not be carbon copied to the output. */
-		GetIntVector=1 << 8,			/**< Try to fetch result as an array of integers */
-		GetStringVector=1 << 9,	/**< Try to fetch result as an array of chars */
-		GetRealVector=1 << 10,		/**< Try to fetch result as an array of doubles */
-		GetStructuredData=1 << 11,		/**< Try to fetch result as an RData structure */
-		CCOutput=1 << 12,		/**< Append command output to the HTML-output file */
-		CCCommand=1 << 13,		/**< Append the command itself to the HTML-output file */
-		ObjectListUpdate=1 << 14,		/**< The command may change the list of objects available. Do an update */
-		QuitCommand=1 << 15		/**< The R backend should be killed */
+		User=1,               /**< Command was created directly by the user (e.g. in the console or in a command editor window) */
+		Plugin=1 << 1,        /**< Command comes from a plugin */
+		App=1 << 2,           /**< Command comes from the application (e.g. loading / saving the workspace */
+		Sync=1 << 3,          /**< Command is used to sync data to or from R-space. Typically used in the editor classes */
+		EmptyCommand=1 << 4,  /**< Command is empty and will not be processed (an empty command may be used as a "marker") */
+		Console=1 << 5,       /**< Command originated in the console. These commands will get some extra treatment in RKwatch */
+		Internal=1 << 6,      /**< Command is meant to be used in the backend, only. Do not use outside rbackend classes! */
+		Silent=1 << 7,        /**< Command can be interrupted, but is otherwise an internal command. In particular it should not be carbon copied to the output. */
+		GetIntVector=1 << 8,  /**< Try to fetch result as an array of integers */
+		GetStringVector=1 << 9, /**< Try to fetch result as an array of chars */
+		GetRealVector=1 << 10, /**< Try to fetch result as an array of doubles */
+		GetStructuredData=1 << 11, /**< Try to fetch result as an RData structure */
+		CCOutput=1 << 12,     /**< Append command output to the HTML-output file */
+		CCCommand=1 << 13,    /**< Append the command itself to the HTML-output file */
+		ObjectListUpdate=1 << 14, /**< The command may change the list of objects available. Do an update */
+		QuitCommand=1 << 15,  /**< The R backend should be killed */
+		PriorityCommand=1 << 16 /**< The command has high priority, should be run during R's event loop processing. In general, PriorityCommands *must* not have side-effects
+		                             Use only, when absolutely necessary. */
 	};
 	enum CommandStatus {
 		Running=1,						/**< command is currently running */
