@@ -30,13 +30,13 @@ public:
 
 	void publicmsleep (int delay) { msleep (delay); };
 
-	void run ();
+	void run () override;
 
-	void writeRequest (RBackendRequest *request);
-	void requestReceived (RBackendRequest *request);
-	void handleTransmissionError (const QString &message);
+	void writeRequest (RBackendRequest *request) override;
+	void requestReceived (RBackendRequest *request) override;
+	void handleTransmissionError (const QString &message) override;
 private:
-	void timerEvent (QTimerEvent *event);
+	void timerEvent (QTimerEvent *event) override;
 	void flushOutput (bool force);
 	QList<RBackendRequest*> current_sync_requests;	// pointers to the request that we expect a reply for. Yes, internally, this can be several requests.
 	QString servername;
