@@ -23,14 +23,16 @@
 #include "../settings/rksettingsmodulegeneral.h"
 #include "../rkglobals.h"
 
-#include <klocale.h>
+#include <KLocalizedString>
 #include <krandom.h>
-#include <kstandarddirs.h>
+
 #include <QCoreApplication>
 #include <QProcess>
 #include <QLocalServer>
 #include <QLocalSocket>
 #include <QDir>
+#include <QStandardPaths>
+#include <QTime>
 
 #include "../version.h"
 #include "../debug.h"
@@ -38,7 +40,7 @@
 QString findBackendAtPath (const QString &path) {
 	QDir dir (path);
 	dir.makeAbsolute ();
-#ifdef Q_WS_WIN
+#ifdef Q_OS_WIN
 	QString ret = dir.filePath ("rkward.rbackend.exe");
 #else
 	QString ret = dir.filePath ("rkward.rbackend");
@@ -63,16 +65,24 @@ RKFrontendTransmitter::~RKFrontendTransmitter () {
 	RK_ASSERT (!server->isListening ());
 }
 
+QString localeDir () {
+	// adapted from KCatalog::catalogLocaleDir()
+	QString relpath = QStringLiteral ("%1/LC_MESSAGES/rkward.mo").arg (QLocale ().name ().section ('_', 0, 0));
+	QString file = QStandardPaths::locate (QStandardPaths::GenericDataLocation, QStringLiteral ("locale/") + relpath);
+	if (file.isEmpty ()) return QString ();
+	return QFileInfo (file.left (file.size() - relpath.size ())).absolutePath ();
+}
+
 void RKFrontendTransmitter::run () {
 	RK_TRACE (RBACKEND);
 
 	// start server
+	qsrand (QTime::currentTime ().msec ()); // Workaround for some versions of kcoreaddons (5.21.0 through at least 5.34.0). See https://phabricator.kde.org/D5966
 	server = new QLocalServer (this);
 	// we add a bit of randomness to the servername, as in general the servername must be unique
 	// there could be conflicts with concurrent or with previous crashed rkward sessions.
 	if (!server->listen ("rkward" + KRandom::randomString (8))) handleTransmissionError ("Failure to start frontend server: " + server->errorString ());
-	connect (server, SIGNAL (newConnection()), this, SLOT (connectAndEnterLoop()), Qt::QueuedConnection);
-
+	connect (server, &QLocalServer::newConnection, this, &RKFrontendTransmitter::connectAndEnterLoop, Qt::QueuedConnection);
 	// start backend
 	backend = new QProcess (this);
 
@@ -80,50 +90,69 @@ void RKFrontendTransmitter::run () {
 	QStringList env = QProcess::systemEnvironment ();
 	int index = env.indexOf (QRegExp("^LANGUAGE=.*", Qt::CaseInsensitive));
 	if (index >= 0) env.removeAt (index);
-	env.append ("LANGUAGE=" + KGlobal::locale ()->language ());
+	env.append ("LANGUAGE=" + QLocale ().name ().section ('_', 0, 0));
 	backend->setEnvironment (env);
 
 	QStringList args;
-	args.append ("--debug-level=" + QString::number (RK_Debug_Level));
-	args.append ("--server-name=" + server->fullServerName ());
-	args.append ("--rkd-server-name=" + rkd_transmitter->serverName ());
-	args.append ("--data-dir=" + RKSettingsModuleGeneral::filesPath ());
-	args.append ("--locale-dir=" + KGlobal::dirs()->findResourceDir ("locale", KGlobal::locale ()->language () + "/LC_MESSAGES/rkward.mo"));
-	connect (backend, SIGNAL (finished(int,QProcess::ExitStatus)), this, SLOT (backendExit(int)));
+	args.append ("--debug-level=" + QString::number (RK_Debug::RK_Debug_Level));
+	// NOTE: QProcess quotes its arguments, *but* properly passing all spaces and quotes through the R CMD wrapper, seems near(?) impossible on Windows. Instead, we use percent encoding, internally.
+	args.append ("--server-name=" + server->fullServerName ().toUtf8 ().toPercentEncoding ());
+	args.append ("--rkd-server-name=" + rkd_transmitter->serverName ().toUtf8 ().toPercentEncoding ());
+	args.append ("--data-dir=" + RKSettingsModuleGeneral::filesPath ().toUtf8 ().toPercentEncoding ());
+	args.append ("--locale-dir=" + localeDir ().toUtf8 ().toPercentEncoding ());
+	connect (backend, static_cast<void (QProcess::*)(int, QProcess::ExitStatus)>(&QProcess::finished), this, &RKFrontendTransmitter::backendExit);
 	QString backend_executable = findBackendAtPath (QCoreApplication::applicationDirPath ());
+#ifdef Q_OS_MACOS
+	if (backend_executable.isNull ()) backend_executable = findBackendAtPath (QCoreApplication::applicationDirPath () + "../Resources"); // an appropriate location in a standalone app-bundle
+#endif
+	if (backend_executable.isEmpty ()) backend_executable = findBackendAtPath (RKWARD_BACKEND_PATH);
+	if (backend_executable.isNull ()) backend_executable = findBackendAtPath (QCoreApplication::applicationDirPath () + "../lib/libexec");
 	if (backend_executable.isEmpty ()) backend_executable = findBackendAtPath (QCoreApplication::applicationDirPath () + "/rbackend");	// for running directly from the build-dir
-#ifdef Q_WS_MAC
+#ifdef Q_OS_MACOS
         if (backend_executable.isEmpty ()) backend_executable = findBackendAtPath (QCoreApplication::applicationDirPath () + "/../../../rbackend");
 #endif
 	if (backend_executable.isEmpty ()) handleTransmissionError (i18n ("The backend executable could not be found. This is likely to be a problem with your installation."));
 	QString debugger = RKGlobals::startup_options["backend-debugger"].toString ();
+	args.prepend (RKCommonFunctions::windowsShellScriptSafeCommand (backend_executable));
 	if (!debugger.isEmpty ()) {
-		args.prepend (backend_executable);
-		QStringList l = debugger.split (' ');
-		args = l.mid (1) + args;
-		backend->start (l.first (), args, QIODevice::ReadOnly);
-	} else {
-		backend->start (backend_executable, args, QIODevice::ReadOnly);
+		args = debugger.split (' ') + args;
 	}
+	args.prepend ("CMD");
+	if (DL_DEBUG >= RK_Debug::RK_Debug_Level) {
+		qDebug ("%s", qPrintable (qgetenv ("R_BINARY")));
+		qDebug ("%s", qPrintable (args.join ("\n")));
+	}
+	backend->start (qgetenv ("R_BINARY"), args, QIODevice::ReadOnly);
 
 	if (!backend->waitForStarted ()) {
-		handleTransmissionError (i18n ("The backend executable could not be started. Error message was: %1").arg (backend->errorString ()));
+		handleTransmissionError (i18n ("The backend executable could not be started. Error message was: %1", backend->errorString ()));
 	}
 
-	// fetch security token
-	if (!backend->canReadLine ()) backend->waitForReadyRead ();
+	waitForCanReadLine (backend, 3000);
 	token = QString::fromLocal8Bit (backend->readLine ()).trimmed ();
 	backend->closeReadChannel (QProcess::StandardError);
 	backend->closeReadChannel (QProcess::StandardOutput);
 
 	exec ();
 
+	backend->waitForFinished ();
+
 	if (!connection) {
 		RK_ASSERT (false);
 		return;
 	}
 }
 
+void RKFrontendTransmitter::waitForCanReadLine (QIODevice* con, int msecs) {
+	RK_TRACE (RBACKEND);
+
+	// NOTE: On Qt5+Windows, readyReady may actually come in char by char, so calling waitForReadyRead() does not guarantee we will
+	//       see the full line, at all. But also, of course, we want to put some cap on trying. Using a time threshold for this.
+	QTime time;
+	time.start ();
+	while ((!con->canReadLine ()) && (time.elapsed () < msecs)) con->waitForReadyRead (500);
+}
+
 void RKFrontendTransmitter::connectAndEnterLoop () {
 	RK_TRACE (RBACKEND);
 	RK_ASSERT (server->hasPendingConnections ());
@@ -132,14 +161,12 @@ void RKFrontendTransmitter::connectAndEnterLoop () {
 	server->close ();
 
 	// handshake
-	if (!con->canReadLine ()) con->waitForReadyRead (1000);
-	QString token_c = QString::fromLocal8Bit (con->readLine ());
-	token_c.chop (1);
-	if (token_c != token) handleTransmissionError (i18n ("Error during handshake with backend process. Expected token '%1', received token '%2'").arg (token).arg (token_c));
-	if (!con->canReadLine ()) con->waitForReadyRead (1000);
-	QString version_c = QString::fromLocal8Bit (con->readLine ());
-	version_c.chop (1);
-	if (version_c != RKWARD_VERSION) handleTransmissionError (i18n ("Version mismatch during handshake with backend process. Frontend is version '%1' while backend is '%2'.\nPlease fix your installation.").arg (RKWARD_VERSION).arg (version_c));
+	waitForCanReadLine (con, 1000);
+	QString token_c = QString::fromLocal8Bit (con->readLine ()). trimmed ();
+	if (token_c != token) handleTransmissionError (i18n ("Error during handshake with backend process. Expected token '%1', received token '%2'", token, token_c));
+	waitForCanReadLine (con, 1000);
+	QString version_c = QString::fromLocal8Bit (con->readLine ().trimmed ());
+	if (version_c != RKWARD_VERSION) handleTransmissionError (i18n ("Version mismatch during handshake with backend process. Frontend is version '%1' while backend is '%2'.\nPlease fix your installation.", QString (RKWARD_VERSION), version_c));
 
 	setConnection (con);
 }
@@ -189,7 +216,7 @@ void RKFrontendTransmitter::writeRequest (RBackendRequest *request) {
 void RKFrontendTransmitter::handleTransmissionError (const QString &message) {
 	RK_TRACE (RBACKEND);
 
-	connection->close ();
+	if (connection) connection->close ();
 	RBackendRequest* req = new RBackendRequest (false, RBackendRequest::BackendExit);
 	req->params["message"] = message;
 	RKRBackendEvent* event = new RKRBackendEvent (req);
@@ -198,4 +225,3 @@ void RKFrontendTransmitter::handleTransmissionError (const QString &message) {
 	exit ();
 }
 
-#include "rkfrontendtransmitter.moc"
