@@ -33,10 +33,8 @@
 #endif
 #define R_USE_PROTOTPYES 1
 
-extern "C" {
 #include <R_ext/GraphicsEngine.h>
 #include <Rversion.h>
-}
 
 // rcolor typedef added in R 3.0.0
 #ifndef rcolor
@@ -55,6 +53,10 @@ struct RKGraphicsDeviceDesc {
 	QString default_family;
 	QString default_symbol_family;
 	pDevDesc rdevdesc;
+#ifdef _MSC_VER
+	// See RKD_Close()
+	pGEDevDesc rgdevdesc;
+#endif
 };
 
 #include "rkgraphicsdevice_stubs.cpp"
@@ -76,7 +78,11 @@ void RKStartGraphicsDevice (double width, double height, double pointsize, const
 	pDevDesc dev;
 	BEGIN_SUSPEND_INTERRUPTS {
 		/* Allocate and initialize the device driver data */
-		dev = (pDevDesc) calloc (1, sizeof(DevDesc));
+#ifdef _MSC_VER
+		dev = (pDevDesc) malloc (sizeof (DevDesc));
+#else
+		dev = (pDevDesc) calloc (1, sizeof (DevDesc)); // don't really understand this, but R needs it this way (while MSVC hates it)
+#endif
 		// NOTE: The call to RKGraphicsDeviceBackendTransmitter::instance(), here is important beyond error checking. It might *create* the instance and connection, if this is the first use.
 		if (!(dev && RKGraphicsDeviceBackendTransmitter::instance () && desc->init (dev, pointsize, family, bg))) {
 			free (dev);
@@ -89,6 +95,10 @@ void RKStartGraphicsDevice (double width, double height, double pointsize, const
 			pGEDevDesc gdd = GEcreateDevDesc (dev);
 			gdd->displayList = R_NilValue;
 			GEaddDevice2 (gdd, "RKGraphicsDevice");
+#ifdef _MSC_VER
+			// See RKD_Close()
+			desc->rgdevdesc = gdd;
+#endif
 		}
 	} END_SUSPEND_INTERRUPTS;
 
