@@ -26,7 +26,6 @@
 	eval (substitute (attr (x, ".rk.meta") <<- m))
 }
 
-#' @export
 ".rk.set.invalid.field" <- function (x, row, value) {
 	l <- attr (x, ".rk.invalid.fields");
 	if (is.null (l)) l <- list ();
@@ -35,6 +34,41 @@
 	eval (substitute (attr (x, ".rk.invalid.fields") <<- l))
 }
 
+#' Work around some peculiarities in R's handling of levels
+#' @export
+".rk.set.levels" <- function (var, levels) {
+	if (is.factor (var)) {
+		if (is.null (levels)) levels <- NA	# must never set NULL levels on a factor
+		old_l <- levels (var)
+		# using attr (..., "levels) instead of levels (...) in order to bypass checking
+		eval (substitute (attr (var, "levels") <<- levels))
+		if ((length (var) > 0) && (is.null (old_l) || ((length (old_l) == 1L) && is.na (old_l[1L]))))	{
+			# if levels were empty, this means var is all NAs. R will set all to first level, instead, in some cases
+			len <- length (var)
+			eval(substitute(var[1:len] <<- NA))
+		}
+	} else {
+		eval (substitute (attr (var, "levels") <<- levels))
+	}
+}
+
+#' @export
+".rk.set.invalid.fields" <- function (x, set, values, clear) {
+	l <- attr (x, ".rk.invalid.fields");
+	if (is.null (l)) l <- list ();
+
+	if (!missing (set)) {
+		set <- as.character (set)
+		l[set] <- as.character (values)
+	}
+	if (!missing (clear)) {
+		l[as.character (clear)] <- NULL
+	}
+
+	if (length (l) == 0) l <- NULL
+	eval (substitute (attr (x, ".rk.invalid.fields") <<- l))
+}
+
 #' @export
 ".rk.data.frame.insert.row" <- function (x, index=0) {
 	if ((index == 0) || (index > dim (x)[1])) {	# insert row at end
@@ -83,7 +117,7 @@
 ".rk.do.error" <- function () {
 # comment in R sources says, it may not be good to query options during error handling. But what can we do, if R_ShowErrorMessages is not longer exported?
 	if (getOption ("show.error.messages")) {
-		.Call ("rk.do.error", c (geterrmessage ()));
+		.Call ("rk.do.error", c (geterrmessage ()), PACKAGE="(embedding)");
 	}
 }
 
@@ -93,13 +127,13 @@
 #' @export
 ".rk.do.call" <- function (x, args=NULL) {
 	.rk.set.reply (NULL)
-	.Call ("rk.do.command", c (x, args));
+	.Call ("rk.do.command", c (x, args), PACKAGE="(embedding)");
 	return (.rk.variables$.rk.rkreply)
 }
 
 #' @export
 ".rk.do.plain.call" <- function (x, args=NULL, synchronous=TRUE) {
-	.Call ("rk.do.generic.request", c (x, args), isTRUE (synchronous))
+	.Call ("rk.do.generic.request", c (x, args), isTRUE (synchronous), PACKAGE="(embedding)")
 }
 
 #' @export
@@ -207,7 +241,7 @@
 	function (value) {
 		if (!missing (value)) {
 			assign (k, value, envir=.rk.watched.symbols)
-			.Call ("rk.do.command", c ("ws", k));
+			.Call ("rk.do.command", c ("ws", k), PACKAGE="(embedding)");
 #			NOTE: the above is essentially the same a
 #				.rk.do.call ("ws", k);
 #			only minimally faster.
@@ -221,7 +255,7 @@
 #' @export
 ".rk.watch.symbol" <- function (k) {
 	f <- .rk.make.watch.f (k)
-	.Call ("rk.copy.no.eval", k, globalenv(), .rk.watched.symbols);
+	.Call ("rk.copy.no.eval", k, globalenv(), .rk.watched.symbols, PACKAGE="(embedding)");
 	#assign (k, get (k, envir=globalenv ()), envir=.rk.watched.symbols)
 	rm (list=k, envir=globalenv ())
 
@@ -289,7 +323,7 @@
 
 #' @export
 ".rk.get.structure" <- function (x, name, envlevel=0, namespacename=NULL) {
-	.Call ("rk.get.structure", x, as.character (name), as.integer (envlevel), namespacename)
+	.Call ("rk.get.structure", x, as.character (name), as.integer (envlevel), namespacename, PACKAGE="(embedding)")
 }
 
 #' @export
@@ -299,7 +333,7 @@
 
 #' @export
 ".rk.get.structure.global" <- function (name, envlevel=0, namespacename=NULL) {
-	.Call ("rk.get.structure.global", as.character (name), as.integer (envlevel), namespacename)
+	.Call ("rk.get.structure.global", as.character (name), as.integer (envlevel), namespacename, PACKAGE="(embedding)")
 }
 
 #' @export
