@@ -25,7 +25,7 @@
 #' 
 #' \code{rk.select.CRAN.mirror} returns the URL of the chosen mirror, as a
 #'   string.
-#' @author Thomas Friedrichsmeier \email{rkward-devel@@lists.sourceforge.net}
+#' @author Thomas Friedrichsmeier \email{rkward-devel@@kde.org}
 #' @keywords attribute misc utilities
 #' @rdname rk.misc
 #' @examples
@@ -38,6 +38,7 @@
 #' 
 # renames a named object in a data.frame/list without changing it's position
 # TODO: create a generic function instead, that can handle all kinds of renames
+#' @export
 "rk.rename.in.container" <- function (x, old_name, new_name, envir=parent.frame()) {
 	temp <- (names (x) == old_name)
 	i = 1;
@@ -51,6 +52,8 @@
 	error ("Could not find column with given name")
 }
 
+#' @export
+#' @rdname rk.misc
 "rk.make.repos.string" <- function () {
 	x <- getOption ("repos")
 	len <- length (x)
@@ -73,6 +76,8 @@
 }
 
 # a wrapper around chooseCRANmirror() without changing options ("repos"), permanently
+#' @export
+#' @rdname rk.misc
 "rk.select.CRAN.mirror" <- function () {
 	old_repos <- getOption("repos")
 	on.exit (options (repos=old_repos))
@@ -102,14 +107,15 @@
 #'
 #' @return a character vector of packages which are really old
 #'
-#' @author Thomas Friedrichsmeier \email{rkward-devel@@lists.sourceforge.net}
+#' @author Thomas Friedrichsmeier \email{rkward-devel@@kde.org}
 #' @keywords attribute misc utilities
-#' @rdname rk.misc
+#' @rdname rk.old.packages
 #' @examples
 #' 
 #' ## NOT RUN
 #' rk.old.packages()
 #' 
+#' @export
 "rk.old.packages" <- function (lib.loc = NULL, repos = getOption("repos"), contriburl = contrib.url(repos, type), instPkgs = installed.packages(lib.loc = lib.loc),
                              method, available = NULL, checkBuilt = FALSE, type = getOption("pkgType")) {
 	if (is.null (lib.loc)) lib.loc <- .libPaths ()
@@ -129,3 +135,45 @@
 	}
 	old
 }
+
+
+#' Start recording commands that are submitted from RKWard to R
+#' 
+#' To stop recording, supply NULL or "" as filename.
+#' Currently used for the purpose of automated testing, only. Perhaps in the future
+#' this or a similar mechanism could also be added as a user feature.
+#' 
+#' @param filename filename to write to (file will be truncated!).
+#' @param include.all By default, some types of command are filtered (internal synchronisation commands, and run again links). Should these be included?
+#' @export
+#' @rdname rk.record.commands
+"rk.record.commands" <- function (filename, include.all = FALSE) {
+	if (is.null (filename)) filename = ""
+
+	res <- .rk.do.plain.call ("recordCommands", c(as.character (filename), if (include.all) "include.all" else "normal"))
+
+	if (!length (res)) invisible (TRUE)
+	else {
+		warning (res)
+		invisible (FALSE)
+	}
+}
+
+#' Switch language / translation to use in the frontend.
+#'
+#' This feature is mostly intended for the purpose of automated testing, which needs a
+#' defined language to work. It might also be useful for translators, or e.g. to look up
+#' some terms untranslated in special cases where you are more familiar with the English terms than
+#' your native language terms. Note that this will only strings that are translated after the call., only those which get
+#' translated after the call. Most new dialogs you open, and importantly new plugin dialogs should
+#' show strings in the new lanuage, however.
+#' 
+#' To change the language in the backend, use \code{Sys.setenv(LANGUAGE=...)} or \code{Sys.setlocale()}.
+#'
+#' @param LANG language code to use. "C" for no translation, i.e. generally English
+#'
+#' @export
+#' @rdname rk.switch.frontend.language
+"rk.switch.frontend.language" <- function (LANG="C") {
+   .rk.do.plain.call ("switchLanguage", as.character (LANG))
+}
