@@ -23,7 +23,7 @@
 
 class QCheckBox;
 class QComboBox;
-class KIntSpinBox;
+class QSpinBox;
 
 /**
 Settings module for the console. Allows you to configure whether to store command history, command history length. Future extensions: color for warnings/errors, etc.
@@ -40,8 +40,8 @@ public:
 	static void saveSettings (KConfig *config);
 	static void loadSettings (KConfig *config);
 	
-	void applyChanges ();
-	void save (KConfig *config);
+	void applyChanges () override;
+	void save (KConfig *config) override;
 
 	static bool saveHistory () { return save_history; };
 	static uint maxHistoryLength () { return max_history_length; };
@@ -61,9 +61,9 @@ public:
 	static QStringList loadCommandHistory ();
 	static void saveCommandHistory (const QStringList &list);
 
-	QString caption ();
+	QString caption () override;
 
-	QString helpURL () { return ("rkward://page/rkward_console#settings"); };
+	QUrl helpURL () override { return QUrl ("rkward://page/rkward_console#settings"); };
 public slots:
 	void changedSetting (int);
 private:
@@ -78,8 +78,8 @@ private:
 	QCheckBox *reverse_context_mode_box;
 	QCheckBox *pipe_user_commands_through_console_box;
 	QComboBox *add_piped_commands_to_history_box;
-	KIntSpinBox *max_history_length_spinner;
-	KIntSpinBox *max_console_lines_spinner;
+	QSpinBox *max_history_length_spinner;
+	QSpinBox *max_console_lines_spinner;
 };
 
 #endif
