@@ -2,8 +2,8 @@
                           detachedwindowcontainer  -  description
                              -------------------
     begin                : Wed Oct 21 2005
-    copyright            : (C) 2005, 2007, 2009, 2010 by Thomas Friedrichsmeier
-    email                : tfry@users.sourceforge.net
+    copyright            : (C) 2005-2016 by Thomas Friedrichsmeier
+    email                : thomas.friedrichsmeier@kdemail.net
  ***************************************************************************/
 
 /***************************************************************************
@@ -17,9 +17,8 @@
 
 #include "detachedwindowcontainer.h"
 
-#include <klocale.h>
+#include <KLocalizedString>
 #include <kactioncollection.h>
-#include <kstatusbar.h>
 #include <ktoolbar.h>
 #include <kxmlguifactory.h>
 
@@ -27,6 +26,7 @@
 #include <qwidget.h>
 #include <QCloseEvent>
 #include <QMenu>
+#include <QStatusBar>
 
 #include "rktoplevelwindowgui.h"
 #include "../rkward.h"
@@ -37,7 +37,7 @@
 #include "../debug.h"
 
 /* Warning! Do not pass a parent widget to the KParts::MainWindow. Otherwise there will be strange crahes while removing the KXMLGUIClients! (In this case: Open a help window, and detach it. Open another help window attached. Close the detached one, then close the attached one -> crash; KDE 3.5.5) */
-DetachedWindowContainer::DetachedWindowContainer (RKMDIWindow *widget_to_capture) : KParts::MainWindow  () {
+DetachedWindowContainer::DetachedWindowContainer (RKMDIWindow *widget_to_capture, bool copy_geometry) : KParts::MainWindow  () {
 	RK_TRACE (APP);
 
 	actionCollection ()->addAction (KStandardAction::Close, "dwindow_close", this, SLOT(close()));
@@ -61,17 +61,18 @@ DetachedWindowContainer::DetachedWindowContainer (RKMDIWindow *widget_to_capture
 	}
 
 // capture widget
-// NOTE: If the window has not been shown, before, its geometry() is always 640*480, unconditionally.
-	setGeometry (widget_to_capture->frameGeometry ());
-	if (!widget_to_capture->isWindow ()) move (widget_to_capture->mapToGlobal (widget_to_capture->pos ()));
-#ifdef Q_WS_WIN
-	// fix for detached tool windows positioned with the frame outside the screen
-	ensurePolished ();
-	QPoint adjust = pos ();
-	if (adjust.x () < 0) adjust.setX (0);
-	if (adjust.y () < 0) adjust.setY (0);
-	if (adjust != pos ()) move (adjust);
+	if (copy_geometry) {
+		setGeometry (widget_to_capture->frameGeometry ());
+		if (!widget_to_capture->isWindow ()) move (widget_to_capture->mapToGlobal (widget_to_capture->pos ()));
+#ifdef Q_OS_WIN
+		// fix for detached tool windows positioned with the frame outside the screen
+		ensurePolished ();
+		QPoint adjust = pos ();
+		if (adjust.x () < 0) adjust.setX (0);
+		if (adjust.y () < 0) adjust.setY (0);
+		if (adjust != pos ()) move (adjust);
 #endif
+	}
 	widget_to_capture->setParent (this);
 	setCentralWidget (widget_to_capture);
 	widget_to_capture->show ();
@@ -80,8 +81,7 @@ DetachedWindowContainer::DetachedWindowContainer (RKMDIWindow *widget_to_capture
 
 	hideEmptyMenus ();
 	// hide empty menus now, and after any reloads
-	// the signal is available since KDE 4.1.3, but we can tolerate a bit of aesthethic malfunction on earlier versions
-	connect (guiFactory (), SIGNAL(makingChanges(bool)), this, SLOT(hideEmptyMenus(bool)));
+	connect (guiFactory (), &KXMLGUIFactory::makingChanges, this, &DetachedWindowContainer::hideEmptyMenus);
 
 // sanitize toolbars
 	foreach (KToolBar *bar, toolBars ()) {
@@ -93,8 +93,8 @@ DetachedWindowContainer::DetachedWindowContainer (RKMDIWindow *widget_to_capture
 	}
 
 // should self-destruct, when child widget is destroyed
-	connect (widget_to_capture, SIGNAL (destroyed (QObject *)), this, SLOT (viewDestroyed (QObject *)));
-	connect (widget_to_capture, SIGNAL (captionChanged (RKMDIWindow *)), this, SLOT (updateCaption (RKMDIWindow *)));
+	connect (widget_to_capture, &QObject::destroyed, this, &DetachedWindowContainer::viewDestroyed);
+	connect (widget_to_capture, &RKMDIWindow::captionChanged, this, &DetachedWindowContainer::updateCaption);
 	setCaption (widget_to_capture->fullCaption ());	// has to come after createGUI!
 }
 
@@ -109,7 +109,7 @@ void DetachedWindowContainer::hideEmptyMenus (bool ignore) {
 	// remove empty menus (we had to define them in detachedwindowcontainer.rc in order to force a sane menu order)
 	QStringList menu_names;
 	menu_names << "file" << "device" << "history" << "edit" << "run" << "view" << "settings";
-	foreach (QString name, menu_names) {
+	foreach (const QString& name, menu_names) {
 		QMenu* menu = dynamic_cast<QMenu*>(guiFactory ()->container (name, this));
 		if (menu) menu->menuAction ()->setVisible (!menu->isEmpty ());
 	}
@@ -133,7 +133,7 @@ void DetachedWindowContainer::slotSetStatusBarText (const QString &text) {
 	RK_TRACE (APP);
 
 	QString ntext = text.trimmed ();
-	ntext.replace ("<qt>", "");	// WORKAROUND: what the ?!? is going on? The KTHMLPart seems to post such messages.
+	ntext.replace ("<qt>", QString ());	// WORKAROUND: what the ?!? is going on? The KTHMLPart seems to post such messages.
 
 	statusBar ()->showMessage (ntext);
 	statusBar ()->show ();
@@ -155,4 +155,3 @@ void DetachedWindowContainer::closeEvent (QCloseEvent *e) {
 	}
 }
 
-#include "detachedwindowcontainer.moc"
