@@ -2,7 +2,7 @@
                           rkmdiwindow  -  description
                              -------------------
     begin                : Tue Sep 26 2006
-    copyright            : (C) 2006, 2007, 2008, 2009, 2010, 2011 by Thomas Friedrichsmeier
+    copyright            : (C) 2006 - 2017 by Thomas Friedrichsmeier
     email                : thomas.friedrichsmeier@kdemail.net
  ***************************************************************************/
 
@@ -22,12 +22,14 @@
 #include <qtimer.h>
 #include <QEvent>
 #include <QPaintEvent>
+#include <QAction>
+#include <QVBoxLayout>
 
-#include <kparts/event.h>
+#include <kparts/partactivateevent.h>
 #include <kxmlguifactory.h>
 #include <kactioncollection.h>
-#include <klocale.h>
-#include <kaction.h>
+#include <KLocalizedString>
+#include <kmessagewidget.h>
 
 #include "rkworkplace.h"
 #include "rkworkplaceview.h"
@@ -36,13 +38,14 @@
 #include "../settings/rksettingsmodulegeneral.h"
 #include "../misc/rkstandardicons.h"
 #include "../misc/rkxmlguisyncer.h"
+#include "../rbackend/rcommand.h"
 
 #include "../debug.h"
 
 RKMDIStandardActionClient::RKMDIStandardActionClient () : KXMLGUIClient () {
 	RK_TRACE (APP);
 
-	setComponentData (KGlobal::mainComponent ());
+	setComponentName (QCoreApplication::applicationName (), QGuiApplication::applicationDisplayName ());
 	setXMLFile ("rkstandardactions.rc", true);
 }
 
@@ -65,7 +68,10 @@ RKMDIWindow::RKMDIWindow (QWidget *parent, int type, bool tool_window, const cha
 	tool_window_bar = 0;
 	part = 0;
 	active = false;
+	no_border_when_active = false;
 	standard_client = 0;
+	status_popup = 0;
+	status_popup_container = 0;
 
 	setWindowIcon (RKStandardIcons::iconForWindow (this));
 }
@@ -109,6 +115,11 @@ bool RKMDIWindow::isActive () {
 	// don't trace, called pretty often
 
 	if (!topLevelWidget ()->isActiveWindow ()) return false;
+	return isActiveInsideToplevelWindow ();
+}
+
+bool RKMDIWindow::isActiveInsideToplevelWindow () {
+	// don't trace, called pretty often
 	return (active || (!isAttached ()));
 }
 
@@ -125,7 +136,7 @@ void RKMDIWindow::activate (bool with_focus) {
 			topLevelWidget ()->raise ();
 		}
 	} else {
-		if (isAttached ()) RKWorkplace::mainWorkplace ()->view ()->setActivePage (this);
+		if (isAttached ()) RKWorkplace::mainWorkplace ()->view ()->showWindow (this);
 		else {
 			topLevelWidget ()->show ();
 			topLevelWidget ()->raise ();
@@ -244,7 +255,7 @@ void RKMDIWindow::paintEvent (QPaintEvent *e) {
 
 	QFrame::paintEvent (e);
 
-	if (isActive ()) {
+	if (isActive () && !no_border_when_active) {
 		QPainter paint (this);
 		paint.setPen (QColor (255, 0, 0));
 		paint.drawLine (0, 0, 0, height ()-1);
@@ -254,17 +265,47 @@ void RKMDIWindow::paintEvent (QPaintEvent *e) {
 	}
 }
 
-void RKMDIWindow::windowActivationChange (bool) {
+void RKMDIWindow::changeEvent (QEvent *event) {
 	RK_TRACE (APP);
 
-	// NOTE: active is NOT the same as isActive(). Active just means that this window *would* be active, if its toplevel window is active.
-	if (active || (!isAttached ())) update ();
+	if (event->type () == QEvent::ActivationChange) {
+		// NOTE: active is NOT the same as isActive(). Active just means that this window *would* be active, if its toplevel window is active.
+		if (active || (!isAttached ())) update ();
+	}
+	QFrame::changeEvent (event);
 }
 
-void RKMDIWindow::slotActivate () {
+void RKMDIWindow::slotActivateForFocusFollowsMouse () {
 	RK_TRACE (APP);
 
+	if (!underMouse ()) return;
+
+	// we can't do without activateWindow(), below. Unfortunately, this has the side effect of raising the window (in some cases). This is not always what we want, e.g. if a 
+	// plot window is stacked above this window. (And since this is activation by mouse hover, this window is already visible, by definition!)
+	// So we try a heuristic (imperfect) to find, if there are any other windows stacked above this one, in order to re-raise them above this.
+	QWidgetList toplevels = qApp->topLevelWidgets ();
+	QWidgetList overlappers;
+	QWidget *window = topLevelWidget ();
+	QRect rect = window->frameGeometry ();
+	for (int i = toplevels.size () - 1; i >= 0; --i) {
+		QWidget *tl = toplevels[i];
+		if (!tl->isWindow ()) continue;
+		if (tl == window) continue;
+		if (tl->isHidden ()) continue;
+
+		QRect tlrect = tl->geometry ();
+		QRect intersected = tlrect.intersected (rect);
+		if (!intersected.isEmpty ()) {
+			QWidget *above = qApp->topLevelAt ((intersected.left () +intersected.right ()) / 2, (intersected.top () +intersected.bottom ()) / 2);
+			if (above && (above != window) && (above->isWindow ()) && (!above->isHidden ()) && (overlappers.indexOf (above) < 0)) overlappers.append (above);
+		}
+	}
+
 	activate (true);
+
+	for (int i = 0; i < overlappers.size (); ++i) {
+		overlappers[i]->raise ();
+	}
 }
 
 void RKMDIWindow::enterEvent (QEvent *event) {
@@ -275,9 +316,14 @@ void RKMDIWindow::enterEvent (QEvent *event) {
 			if (!QApplication::activePopupWidget ()) {
 				// see http://sourceforge.net/p/rkward/bugs/90/
 				// enter events may be delivered while a popup-menu (in a different window) is executing. If we activate in this case, the popup-menu might get deleted
-				// while still handling events. Similar problems seem to occur, when the popup menu has just finished (by the user selecting an action) and this results
+				// while still handling events.
+				//
+				// Similar problems seem to occur, when the popup menu has just finished (by the user selecting an action) and this results
 				// in the mouse entering this widget. To prevent crashes in this second case, we delay the activation until the next iteration of the event loop.
-				QTimer::singleShot (0, this, SLOT (slotActivate()));
+				//
+				// Finally, in some cases (such as when a new script window was created), we need a short delay, as we may be catching an enter event on a window that is in the same place,
+				// where the newly created window goes. This would cause activation to switch back, immediately.
+				QTimer::singleShot (50, this, SLOT (slotActivateForFocusFollowsMouse()));
 			}
 		}
 	}
@@ -285,7 +331,67 @@ void RKMDIWindow::enterEvent (QEvent *event) {
 	QFrame::enterEvent (event);
 }
 
-void RKMDIWindow::setMetaInfo (const QString& _generic_window_name, const QString& _help_url, RKSettings::SettingsPage _settings_page) {
+void RKMDIWindow::setStatusMessage (const QString& message, RCommand *command) {
+	RK_TRACE (MISC);
+
+	if (!status_popup) {
+		status_popup_container = new QWidget (this);
+		status_popup_container->resize (size ());
+		QVBoxLayout *layout = new QVBoxLayout (status_popup_container);
+		layout->setContentsMargins (10, 10, 10, 10);
+		status_popup = new KMessageWidget (status_popup_container);
+		status_popup->setCloseButtonVisible (true);
+		status_popup->setMessageType (KMessageWidget::Warning);
+		layout->addWidget (status_popup);
+		layout->addStretch ();
+	}
+
+	if (command) connect (command->notifier (), &RCommandNotifier::commandFinished, this, &RKMDIWindow::clearStatusMessage);
+	if (!message.isEmpty ()) {
+		status_popup_container->show ();
+		if (status_popup->text () == message) {
+			if (!status_popup->isVisible ()) status_popup->animatedShow ();  // it might have been close by user. And no, simply show() is _not_ good enough. KF5 (5.15.0)
+		}
+		if (status_popup->text () != message) {
+			if (status_popup->isVisible ()) status_popup->hide (); // otherwise, the KMessageWidget does not update geometry (KF5, 5.15.0)
+			status_popup->setText (message);
+			status_popup->animatedShow ();
+		}
+	} else {
+		status_popup_container->hide ();
+		status_popup->hide ();
+		status_popup->setText (QString ());  // this is a lame way to keep track of whether the popup is empty. See resizeEvent()
+	}
+}
+
+void RKMDIWindow::clearStatusMessage () {
+	RK_TRACE (APP);
+
+	setStatusMessage (QString ());
+}
+
+void RKMDIWindow::resizeEvent (QResizeEvent*) {
+	if (status_popup_container && !status_popup->text ().isEmpty ()) {
+		status_popup_container->resize (size ());
+	}
+}
+
+
+void RKMDIWindow::setWindowStyleHint (const QString& hint) {
+	RK_TRACE (APP);
+
+	if (hint == "preview") {
+		if (standard_client) {
+			QAction *act = standardActionCollection ()->action ("window_help");
+			if (act) act->setVisible (false);
+			act = standardActionCollection ()->action ("window_configure");
+			if (act) act->setVisible (false);
+		}
+		no_border_when_active = true;
+	}
+}
+
+void RKMDIWindow::setMetaInfo (const QString& _generic_window_name, const QUrl& _help_url, RKSettings::SettingsPage _settings_page) {
 	RK_TRACE (APP);
 
 	// only meant to be called once
@@ -295,11 +401,11 @@ void RKMDIWindow::setMetaInfo (const QString& _generic_window_name, const QStrin
 	settings_page = _settings_page;
 
 	if (!help_url.isEmpty ()) {
-		KAction *action = standardActionCollection ()->addAction ("window_help", this, SLOT (showWindowHelp()));
+		QAction *action = standardActionCollection ()->addAction ("window_help", this, SLOT (showWindowHelp()));
 		action->setText (i18n ("Help on %1", generic_window_name));
 	}
 	if (settings_page != RKSettings::NoPage) {
-		KAction *action = standardActionCollection ()->addAction ("window_configure", this, SLOT (showWindowSettings()));
+		QAction *action = standardActionCollection ()->addAction ("window_configure", this, SLOT (showWindowSettings()));
 		action->setText (i18n ("Configure %1", generic_window_name));
 	}
 }
@@ -319,4 +425,3 @@ void RKMDIWindow::showWindowSettings () {
 }
 
 
-#include "rkmdiwindow.moc"
