@@ -2,6 +2,6 @@ local({
 ## Compute
 write.table ( x =  women , file =  "data" , append =  FALSE  ,quote = TRUE ,  sep = '\t' , eol = "\n" , na = "NA" ,  dec = '.' , row.names =  FALSE ,  col.names =  TRUE , qmethod=  'escape' ) 
 ## Print result
-rk.header("Write as table", parameters=list("File", "data",
-	"Data", "women"))
+rk.header ("Write as table", parameters=list("Name of the file"="data",
+	"Data"="women"))
 })
