@@ -4,7 +4,9 @@ yrange <- range (swiss[["Catholic"]], na.rm=TRUE)
 data.mean <- mean (swiss[["Catholic"]], na.rm=TRUE)
 data.sd <- sd (swiss[["Catholic"]], na.rm=TRUE)
 ## Print result
-rk.header ("Empirical Cumulative Distribution Function", list ("Variable", rk.get.description (swiss[["Catholic"]]), "Minimum", yrange[1], "Maximum", yrange[2]))
+rk.header ("Empirical Cumulative Distribution Function", parameters=list("Variable"=rk.get.description (swiss[["Catholic"]]),
+	"Minimum"=yrange[1],
+	"Maximum"=yrange[2]))
 
 rk.graph.on ()
 try ({
